@@ -17,14 +17,13 @@
 System-level utilities and helper functions.
 """
 
-import collections
+import collections.abc
 import math
 import re
 import unicodedata
+import urllib
 
 import pyparsing as pp
-import six
-from six.moves import urllib
 
 from oslo_utils._i18n import _
 from oslo_utils import encodeutils
@@ -60,7 +59,7 @@ _SANITIZE_KEYS = ['adminpass', 'admin_pass', 'password', 'admin_password',
                   'auth_token', 'new_pass', 'auth_password', 'secret_uuid',
                   'secret', 'sys_pswd', 'token', 'configdrive',
                   'chappassword', 'encrypted_key', 'private_key',
-                  'encryption_key_id', 'fernetkey', 'sslkey', 'passphrase',
+                  'fernetkey', 'sslkey', 'passphrase',
                   'cephclusterfsid', 'octaviaheartbeatkey', 'rabbitcookie',
                   'cephmanilaclientkey', 'pacemakerremoteauthkey',
                   'designaterndckey', 'cephadminkey', 'heatauthencryptionkey',
@@ -80,6 +79,8 @@ _SANITIZE_PATTERNS_WILDCARD = {}
 # have two parameters. Use different lists of patterns here.
 _FORMAT_PATTERNS_1 = [r'(%(key)s[0-9]*\s*[=]\s*)[^\s^\'^\"]+']
 _FORMAT_PATTERNS_2 = [r'(%(key)s[0-9]*\s*[=]\s*[\"\'])[^\"\']*([\"\'])',
+                      r'(%(key)s[0-9]*\s*[=]\s*[\"])[^\"]*([\"])',
+                      r'(%(key)s[0-9]*\s*[=]\s*[\'])[^\']*([\'])',
                       r'(%(key)s[0-9]*\s+[\"\'])[^\"\']*([\"\'])',
                       r'([-]{2}%(key)s[0-9]*\s+)[^\'^\"^=^\s]+([\s]*)',
                       r'(<%(key)s[0-9]*>)[^<]*(</%(key)s[0-9]*>)',
@@ -145,8 +146,8 @@ def bool_from_string(subject, strict=False, default=False):
     """
     if isinstance(subject, bool):
         return subject
-    if not isinstance(subject, six.string_types):
-        subject = six.text_type(subject)
+    if not isinstance(subject, str):
+        subject = str(subject)
 
     lowered = subject.strip().lower()
 
@@ -331,7 +332,7 @@ def mask_password(message, secret="***"):  # nosec
     """
 
     try:
-        message = six.text_type(message)
+        message = str(message)
     except UnicodeDecodeError:  # nosec
         # NOTE(jecarey): Temporary fix to handle cases where message is a
         # byte string. A better solution will be provided in Kilo.
@@ -413,18 +414,18 @@ def mask_dict_password(dictionary, secret="***"):  # nosec
 
     """
 
-    if not isinstance(dictionary, collections.Mapping):
+    if not isinstance(dictionary, collections.abc.Mapping):
         raise TypeError("Expected a Mapping, got %s instead."
                         % type(dictionary))
     out = {}
     for k, v in dictionary.items():
-        if isinstance(v, collections.Mapping):
+        if isinstance(v, collections.abc.Mapping):
             out[k] = mask_dict_password(v, secret=secret)
             continue
         # NOTE(jlvillal): Check to see if anything in the dictionary 'key'
         # contains any key specified in _SANITIZE_KEYS.
         k_matched = False
-        if isinstance(k, six.string_types):
+        if isinstance(k, str):
             for sani_key in _SANITIZE_KEYS:
                 if sani_key in k.lower():
                     out[k] = secret
@@ -433,7 +434,7 @@ def mask_dict_password(dictionary, secret="***"):  # nosec
         if not k_matched:
             # We did not find a match for the key name in the
             # _SANITIZE_KEYS, so we fall through to here
-            if isinstance(v, six.string_types):
+            if isinstance(v, str):
                 out[k] = mask_password(v, secret=secret)
             else:
                 # Just leave it alone.
@@ -451,7 +452,7 @@ def is_int_like(val):
     .. versionadded:: 1.1
     """
     try:
-        return six.text_type(int(val)) == six.text_type(val)
+        return str(int(val)) == str(val)
     except (TypeError, ValueError):
         return False
 
@@ -470,7 +471,7 @@ def check_string_length(value, name=None, min_length=0, max_length=None):
     if name is None:
         name = value
 
-    if not isinstance(value, six.string_types):
+    if not isinstance(value, str):
         msg = _("%s is not a string or unicode") % name
         raise TypeError(msg)
 
